class BreakagesDashboard < RxModule::Dashboards::CategoryChart
  expose('rx_breakages', 'Breakages Breakdown', 'Tracks breakages in Rx-Universe')
  targets("Breakage Type", "Include jobs broken with the selected reason(s)", -> { breakage_targets })

  ui_hint(category: 'Breakages')

  def build_results!
    breakages = RxModule::Communicator::Rxuniverse.breakages
    total = RxModule::Communicator::Rxuniverse.wip_breakdown[:'num-total'].to_f
    targets.each do |target|
      converted_target = target.gsub('%', '').to_s
      breakage = breakages.find { |b| b[:code].to_s == converted_target }
      if breakage
        if target[0] == '%'
          if total == 0
            push_point('breakages', 0, target)
          else
            push_point('breakages', ((breakage[:num].to_f / total) * 100).round(2), target)
          end
        else
          push_point('breakages', breakage[:num], target)
        end
      else
        push_point('breakages', 0, target)
      end
    end
  end

  def series_name(id)
    "Breakages"
  end

  def standard_category_names
    BreakagesDashboard.standard_category_names
  end

  class << self
    def breakage_targets
      begin
        breakage_codes = RxModule::Communicator::Rxuniverse.breakage_codes
        breakage_codes.map do |c|
          {label: "#{c[:desc]} (Count)", value: c[:code], group: "Count", description: "Number of jobs broken today flagged with reason #{c[:desc]}"}
        end + breakage_codes.map do |c|
          {label: "#{c[:desc]} (%)", value: "%#{c[:code]}", group: "% Today's Jobs", description: "Number of jobs broken today flagged with reason #{c[:desc]} / Total Number of Jobs Processed Today"}
        end
      rescue StandardError => err
        []
      end
    end

    def standard_category_names
      breakage_targets.map do |defn|
        [defn[:value], defn[:label]]
      end.to_h
    end
  end
end