class JobsAtStation < RxModule::Dashboards::Table
  expose('jobs_at_station', 'Jobs at Station', 'Lists jobs at one or more job tracker stations')

  column('order-status-station-label', 'Station', 'string')
  column('order-account-num', 'Account', 'string')
  column('order-number', 'Order', 'string')
  column('ord-cust-job-id', 'Customer Job ID', 'string')
  column('ord-wanted-date', 'Wanted', 'date')
  column('order-status-cust-desc', 'Station Customer Description', 'string')
  column('order-status-date-time', 'Status Updated', 'datetime')
  column('order-po-num', 'PO', 'string')
  column('order-patient-name', 'Patient', 'string')
  column('order-tray-num', 'Tray', 'string')
  targets('order-status-station', "Station", "List jobs currently at these stations", -> { stations })

  ui_hint(default_sorts: %w[order-status-station order-status-date-time])
  ui_hint(category: 'Job Tracker')

  def self.stations
    begin
      (RxModule::Communicator::Rxuniverse.job_tracker_stations || []).map do |station|
        {label: station[:desc], value: station[:code]}
      end
    rescue StandardError => err
      []
    end
  end

  def build_results!
    targets.each do |station|
      jobs = RxModule::Communicator::Rxuniverse.jobs_at_station(station)
      if jobs && (jobs.length > 0)
        jobs.each do |job|
          add_row({
                      **job,
                      'order-status-station-label': target_label(station),
                      'order-days-late': job[:'order-days-late'].to_i,
                      'order-status-date-time': RxModule::Time.resolve(Time.strptime("#{job[:'order-status-date']} #{job[:'order-status-time']}", '%Y%m%d %H%M')).strftime('%Y-%m-%d %H:%M'),
                      'ord-wanted-date': RxModule::Time.resolve(Time.strptime(job[:'ord-wanted-date'], '%Y%m%d')).strftime('%Y-%m-%d')
                  })
        end
      else
        add_row({
                    'order-status-station': station,
                    'order-status-station-label': target_label(station)
                })
      end
    end
  end
end