class WipBreakdownDashboard < RxModule::Dashboards::CategoryChart
  expose('rx_wip_breakdown', 'WIP Breakdown', 'Tracks wip in Rx-Universe')
  targets("Categories", "Track jobs that match the selected WIP state(s)", -> { codes })

  ui_hint(category: 'WIP')

  def build_results!
    RxModule::Communicator::Rxuniverse.wip_breakdown.each do |code, val|
      if code == :treats
        val.each do |subcode, subval|
          if is_target? "#{code}.#{subcode}"
            push_point('categories', subval, "#{code}.#{subcode}")
          end
        end
      else
        if is_target? code.to_s
          push_point('categories', val, code)
        end
      end
    end
  end

  def series_name(id)
    "WIP"
  end

  def standard_category_names
    WipBreakdownDashboard.standard_category_names
  end

  class << self
    def codes
      [
          {value: 'num-total', label: 'All Jobs Count', group: 'Overall'},
          {value: 'num-completed-today', label: 'Completed Today', group: 'Overall'},
          {value: 'num-in-today', label: 'In Today', group: 'Overall'},
          {value: 'num-valid', label: 'Valid', group: 'Status'},
          {value: 'num-unvalid', label: 'Unvalid', group: 'Status'},
          {value: 'num-late', label: 'Late', group: 'Status'},
          {value: 'num-uncuts', label: 'Uncut', group: 'Type'},
          {value: 'num-full', label: 'Full', group: 'Type'},
          {value: 'num-finished', label: 'Finished', group: 'Type'},
          {value: 'num-cr39', label: 'CR39', group: 'Material'},
          {value: 'num-poly', label: 'Poly', group: 'Material'},
          {value: 'num-glass', label: 'Glass', group: 'Material'},
          {value: 'num-trivex', label: 'Trivex', group: 'Material'},
          {value: 'num-mid-index', label: 'Mid-Index', group: 'Material'},
          {value: 'num-hi-index', label: 'Hi-Index', group: 'Material'},
          {value: 'num-toric', label: 'Toric', group: 'Toric'},
          {value: 'num-digital', label: 'Digital', group: 'Digital'},
          {value: 'num-sv-digital', label: 'SV Digital', group: 'Digital'},
          {value: 'num-sv-toric', label: 'SV Toric', group: 'Toric'},
          {value: 'num-bifocal-digital', label: 'Bifocal Digital', group: 'Digital'},
          {value: 'num-bifocal-toric', label: 'Bifocal Toric', group: 'Toric'},
          {value: 'num-prog-digital', label: 'Prog Digital', group: 'Digital'},
          {value: 'num-prog-toric', label: 'Prog Toric', group: 'Toric'},
      ] + dynamic_codes.map do |code, label|
        {value: code, label: label, group: 'Treatments'}
      end
    end

    def standard_category_names
      codes.map { |defn| [defn[:value], defn[:label]] }.to_h
    end

    def dynamic_codes
      begin
        RxModule::Communicator::Rxuniverse.pretreatment_codes.map do |c|
          ["treats.#{c[:code]}", c[:desc]]
        end.to_h
      rescue StandardError => err
        {}
      end
    end
  end
end