class WipTrendDashboard < RxModule::Dashboards::DualAxisChart
  expose('rx_wip_trend', 'WIP Trend', 'Tracks wip in Rx-Universe')
  parameter(:days, "Days of Data", "How many days to go back when fetching data", :integer, default: 7, min: 1, max: 30)
  targets("Categories", "Which WIP states to track", -> { category_dropdown_values })

  ui_hint(category: 'WIP')

  def build_results!
    (@parameters[:targets] || standard_category_names.keys).each do |s|
      if !@parameters[:targets] || @parameters[:targets]&.find { |c| c.to_s == s.to_s }
        push_series(s.to_s, standard_category_names[s.to_sym])
      end
    end
    oldest_date = RxModule::Time.now - (@parameters[:days] || 7).days
    RxModule::Communicator::Rxuniverse.wip30.reverse.each do |day|
      parsed_date = RxModule::Time.resolve(Time.strptime(day[:date], '%Y%m%d'))
      if parsed_date >= oldest_date
        day.each do |code, val|
          if is_target? code
            push_point(code.to_s, parsed_date.strftime('%Y-%m-%d'), val)
          end
        end
      end
    end
  end

  def series_name(id)
    "WIP"
  end

  def standard_category_names
    WipTrendDashboard.standard_category_names
  end

  class << self
    def standard_category_names
      {
          "jobs-in": 'In',
          "jobs-completed": 'Out',
          "jobs-wip": 'WIP',
          "jobs-cancelled": 'Cancelled',
          "jobs-transferred": 'Transferred',
      }
    end

    def category_dropdown_values
      standard_category_names.map do |k, v|
        {label: v, value: k}
      end
    end
  end
end