# == Schema Information
#
# Table name: addon_charges
#
#  id         :bigint           not null, primary key
#  addoncode  :string
#  addondesc  :string
#  addonprice :decimal(12, 3)
#  created_at :datetime         not null
#  updated_at :datetime         not null
#  order_id   :bigint
#
# Indexes
#
#  index_addon_charges_on_addoncode  (addoncode)
#  index_addon_charges_on_order_id   (order_id)
#
# Foreign Keys
#
#  fk_rails_...  (order_id => orders.id) ON DELETE => cascade ON UPDATE => cascade
#
class AddonCharge < ApplicationRecord
  belongs_to :order

  reportable("addon_charge", "Addon Charges", "Report on addon charges", {
      addondesc: {
          name: "Description",
          shortname: "Addon",
          desc: "Description of addon service performed in the lab"
      },
      addoncode: {
          name: "Code",
          shortname: "Addon",
          desc: "Addon service performed in the lab"
      },
      addonprice: {
          name: "Price",
          desc: "Price charged by the lab for performing the service"
      },
      order: {
          name: "Order",
          desc: "The order the addon was applied to"
      }
  }, permission_id: 'order')
end
