class ApplicationRecord < RxModule::ApplicationRecord
  self.abstract_class = true

  def should_broadcast?
    false
  end

  class << self
    def import_from_hash(h)
      unsupported = {}
      associations = {}
      h.each do |attr, attr_val|
        if (definition = self.columns_hash[attr])
          case definition.type
          when :boolean
            if attr_val.is_a?(String)
              h[attr] = %w(1 t true y yes).include?(attr_val.downcase)
            end
          end
        elsif (klass = self.reflect_on_association(attr)&.klass)
          if is_multiple_association?(attr)
            attr_val = [attr_val] unless attr_val.is_a?(Array)
            attr_val.reject! { |a| a.nil? }
            associations[attr] = attr_val.map { |c| klass.import_from_hash(c) }
          else
            associations[attr] = attr_val ? klass.import_from_hash(attr_val) : nil
          end
          h[attr] = attr_val.is_a?(Array) ? attr_val.map { |c| klass.import_from_hash(c) } : klass.import_from_hash(attr_val)
        else
          unsupported[attr] = attr_val
        end
      end
      associations.each do |asc_name, _|
        h.delete(asc_name)
      end
      if unsupported.size > 0
        Rails.logger.warn { {import_issue: "Unrecognized attributes provided in import", import_class: name, attributes: unsupported} }
        unsupported.each do |attr, _|
          h.delete(attr)
        end
      end
      obj = (self.conflict_target && where(self.conflict_target.map do |c|
        [c, h[c.to_s]]
      end.to_h).first) || self.new
      obj.assign_attributes(h)
      associations.each do |asc_name, asc_obj|
        if destroy_old_on_import?(asc_name) && (old_val = obj.send(asc_name))
          if is_multiple_association?(asc_name)
            old_val.clear
          else
            old_val.delete
          end
        end
        if append_on_import?(asc_name)
          obj.send(asc_name) << asc_obj
        else
          obj.send("#{asc_name}=", asc_obj)
        end
      end
      obj
    end

    def conflict_target
      nil
    end

    def destroy_old_on_import?(assoc)
      false
    end

    def append_on_import?(assoc)
      false
    end

    def clean_multi_relation(entity)
      unless entity.is_a?(Array)
        entity = [entity]
      end
      entity.select do |item|
        (!item.nil?) &&
            (item != '') &&
            (!item.respond_to?(:values) || item.values.any? do |attr_val|
              (!attr_val.nil?) &&
                  (attr_val != '') &&
                  (!attr_val.respond_to?(:to_i) || attr_val.to_i != 0)
            end)
      end # scrub empty relations (coming from the xml)
    end
  end
end
