# == Schema Information
#
# Table name: job_tracker_histories
#
#  id         :bigint           not null, primary key
#  jtdatetime :datetime
#  jtdesc     :string
#  jtmessage  :string
#  jtoperator :string
#  jtstation  :string
#  created_at :datetime         not null
#  updated_at :datetime         not null
#  order_id   :bigint
#
# Indexes
#
#  index_job_tracker_histories_on_jtdatetime  (jtdatetime)
#  index_job_tracker_histories_on_jtstation   (jtstation)
#  index_job_tracker_histories_on_order_id    (order_id)
#
# Foreign Keys
#
#  fk_rails_...  (order_id => orders.id) ON DELETE => cascade ON UPDATE => cascade
#
class JobTrackerHistory < ApplicationRecord
  belongs_to :order, optional: true

  reportable("job_tracker_history", "Job Tracker History", "Report on job tracker station visits", {
      jtdatetime: {
          name: "Station Checkin Time",
          shortname: "Time",
          desc: "The time the job tracker history entry was generated"
      },
      jtstation: {
          name: "Station",
          desc: "The station the job visited"
      },
      jtdesc: {
          name: "Station Description",
          shortname: "Desc",
          desc: "Action applicable to the station"
      },
      jtmessage: {
          name: "Station Message",
          shortname: "Msg",
          desc: "Message generated by the station"
      },
      jtoperator: {
          name: "Station Operator",
          shortname: "Op",
          desc: "The operator using the station"
      },
      order: {
          name: "Order",
          desc: "The order the tax was applied to"
      }
  })
end
