# == Schema Information
#
# Table name: order_frames
#
#  id                :bigint           not null, primary key
#  framebrand        :string
#  framecollection   :string
#  framecolour       :string
#  framecost         :decimal(12, 3)
#  framedesc         :string
#  framediscountflag :boolean
#  frameid           :string
#  framemanuf        :string
#  framemodel        :string
#  framename         :string
#  framesize         :string
#  framestatus       :string
#  frametaxableflag  :boolean
#  ismisc            :boolean
#  ispart            :boolean
#  created_at        :datetime         not null
#  updated_at        :datetime         not null
#  order_id          :bigint
#
# Indexes
#
#  index_order_frames_on_framecost    (framecost)
#  index_order_frames_on_frameid      (frameid)
#  index_order_frames_on_framestatus  (framestatus)
#  index_order_frames_on_order_id     (order_id)
#
# Foreign Keys
#
#  fk_rails_...  (order_id => orders.id) ON DELETE => cascade ON UPDATE => cascade
#
class OrderFrame < ApplicationRecord
  belongs_to :order

  reportable("order_frame", "Order Frames", "Report on frames attached to orders", {
      framestatus: {
          name: "Status",
          desc: "The status of the frame"
      },
      framename: {
          name: "Name",
          desc: "The name of the frame"
      },
      framemodel: {
          name: "Model",
          desc: "The model of the frame"
      },
      framebrand: {
          name: "Brand",
          desc: "The brand of the frame"
      },
      framemanuf: {
          name: "Manufacturer",
          desc: "The manufacturer of the frame"
      },
      framecollection: {
          name: "Collection",
          desc: "The collection of the frame"
      },
      framecolour: {
          name: "Color",
          desc: "The color of the frame"
      },
      framesize: {
          name: "Size",
          desc: "The size of the frame"
      },
      framecost: {
          name: "Cost",
          desc: "The cost of the frame"
      },
      framediscountflag: {
          name: "Discount?",
          desc: "Whether or not discount applies to the frame"
      },
      frametaxableflag: {
          name: "Tax?",
          desc: "Whether or not taxes apply to the frame"
      },
      framedesc: {
          name: "Notes",
          desc: "Additional notes about the frame"
      },
      ispart: {
          name: "Part?",
          desc: "True if the frame is a frame part"
      },
      ismisc: {
          name: "Misc?",
          desc: "True if the frame is a miscellaneous item"
      },
      order: {
          name: "Order",
          desc: "The order the frame was attached to"
      }
  }, permission_id: 'order')
end
