# == Schema Information
#
# Table name: order_remarks
#
#  id         :bigint           not null, primary key
#  remark     :string
#  created_at :datetime         not null
#  updated_at :datetime         not null
#  order_id   :bigint
#
# Indexes
#
#  index_order_remarks_on_order_id  (order_id)
#
# Foreign Keys
#
#  fk_rails_...  (order_id => orders.id) ON DELETE => cascade ON UPDATE => cascade
#
class OrderRemark < ApplicationRecord
  belongs_to :order, optional: true

  class << self
    def import_from_hash(h)
      if h.is_a?(String)
        h = {"remark" => h}
      end
      super(h)
    end
  end

  reportable("order_remark", "Order Remarks", "Report on order remarks", {
      remark: {
          name: "Remark",
          desc: "The remark attached to the order"
      },
      order: {
          name: "Order",
          desc: "The order the remark was applied to"
      }
  }, permission_id: 'order')
end
