# == Schema Information
#
# Table name: order_stock_items
#
#  id            :bigint           not null, primary key
#  stockcomm     :boolean
#  stockcost     :decimal(12, 3)
#  stockdesc     :string
#  stockdisc     :boolean
#  stockitemtype :string
#  stocklr       :boolean
#  stocknum      :string
#  stockpatient  :string
#  stockprice    :decimal(12, 3)
#  stockqty      :integer
#  stockqtylt    :integer
#  stockqtyrt    :integer
#  stocktxble    :boolean
#  created_at    :datetime         not null
#  updated_at    :datetime         not null
#  order_id      :bigint
#
# Indexes
#
#  index_order_stock_items_on_order_id    (order_id)
#  index_order_stock_items_on_stocknum    (stocknum)
#  index_order_stock_items_on_stockqty    (stockqty)
#  index_order_stock_items_on_stockqtylt  (stockqtylt)
#  index_order_stock_items_on_stockqtyrt  (stockqtyrt)
#
# Foreign Keys
#
#  fk_rails_...  (order_id => orders.id) ON DELETE => cascade ON UPDATE => cascade
#
class OrderStockItem < ApplicationRecord
  belongs_to :order, optional: true

  reportable("order_stock_item", "Stock Items", "Report on order stock items", {
      stocknum: {
          name: "Stock Number",
          shortname: "Num",
          desc: "The stock number of the lens"
      },
      stockdesc: {
          name: "Stock Description",
          shortname: "Desc",
          desc: "The stock description of the lens"
      },
      stockqty: {
          name: "Stock Quantity",
          shortname: "Qty",
          desc: "The stock quantity of the lens"
      },
      stockqtyrt: {
          name: "Right Stock Quantity",
          shortname: "R.Qty",
          desc: "The stock quantity of the right lens"
      },
      stockqtylt: {
          name: "Left Stock Quantity",
          shortname: "L.Qty",
          desc: "The stock quantity of the left lens"
      },
      stockcost: {
          name: "Stock Cost",
          shortname: "Cost",
          desc: "The cost of the stock item to the lab"
      },
      stockprice: {
          name: "Stock Price",
          shortname: "Price",
          desc: "The price the lab charges for the stock item"
      },
      stockdisc: {
          name: "Discountable?",
          shortname: "Disc",
          desc: "Is the stock item discountable?"
      },
      stocktxble: {
          name: "Taxable?",
          shortname: "Tax",
          desc: "Is the stock item taxable?"
      },
      stocklr: {
          name: "Stock Left/Right Item?",
          shortname: "L/R",
          desc: "Is the stock item a left/right item?"
      },
      stockcomm: {
          name: "Stock Commision?",
          shortname: "Comm",
          desc: "Is the stock item valid for commission?"
      },
      stockpatient: {
          name: "Stock Patient",
          shortname: "Patient",
          desc: "The patient the item is for"
      },
      stockitemtype: {
          name: "Stock Item Type",
          shortname: "Type",
          desc: "The item type of the stock item"
      },
      order: {
          name: "Order",
          desc: "The order the stock item was attached to"
      }
  }, permission_id: 'order')
end
