# == Schema Information
#
# Table name: po_lines
#
#  id                    :bigint           not null, primary key
#  lensqtyonorder        :integer
#  lensqtyonorderleft    :integer
#  lensqtyonorderright   :integer
#  lensqtyreceived       :integer
#  lensqtyreceivedleft   :integer
#  lensqtyreceivedright  :integer
#  lensqtysuggested      :integer
#  lensqtysuggestedleft  :integer
#  lensqtysuggestedright :integer
#  lensstocknum          :string
#  lensunitprice         :decimal(12, 3)
#  lensvendernumber      :string
#  created_at            :datetime         not null
#  updated_at            :datetime         not null
#  lens_id               :bigint
#  po_header_id          :bigint
#
# Indexes
#
#  index_po_lines_on_lens_id           (lens_id)
#  index_po_lines_on_lensstocknum      (lensstocknum)
#  index_po_lines_on_lensvendernumber  (lensvendernumber)
#  index_po_lines_on_po_header_id      (po_header_id)
#
# Foreign Keys
#
#  fk_rails_...  (lens_id => lenses.id) ON DELETE => nullify ON UPDATE => cascade
#  fk_rails_...  (po_header_id => po_headers.id) ON DELETE => cascade ON UPDATE => cascade
#
class PoLine < ApplicationRecord
  belongs_to :po_header, optional: true
  belongs_to :lens, optional: true
  has_many :po_trays, dependent: :destroy

  class << self
    def import_from_hash(h)
      h.merge!({"po_trays" => clean_multi_relation(h.delete("potrays"))})
      h.merge!({"lens" => (h.delete("lenstechnical") || {}).merge((h.delete("lenscharacteristics") || {})).merge((h.delete("polenscharacteristics") || {})).merge((h.delete("polenstechnical") || {}))})
      if h["lens"].nil? || (h["lens"] == {}) || (h["lens"]["lensdescription"].nil? && h["lens"]["polensdescription"].nil?)
        h.delete("lens")
      else
        h["lens"].merge!({"lmssource" => h.delete("lmssource")})
        Lens.columns_hash.keys.map(&:to_s).each do |k|
          unless ['id', 'created_at', 'updated_at'].include?(k)
            h["lens"][k] ||= h["lens"].delete("po#{k}")
          end
        end
      end
      %w(lensstocknum lensqtysuggested lensqtysuggestedright lensqtysuggestedleft lensqtyonorder lensqtyonorderright lensqtyonorderleft lensqtyreceived lensqtyreceivedright lensqtyreceivedleft lensunitprice lensvendernumber).each do |k|
        h[k] ||= h.delete("po#{k}")
      end
      super(h)
    end

    def destroy_old_on_import?(assoc)
      assoc&.to_s == "po_trays"
    end
  end

  reportable("po_line", "Purchase Order Lines", "Report on purchase orders detail entries", {
      lensstocknum: {
          name: "Stock Number",
          shortname: "Stock Num",
          desc: "The stock number attached to this line item"
      },
      lensqtyonorder: {
          name: "Quantity On Order",
          shortname: "Qty On Order",
          desc: "The quantity on order attached to this line item"
      },
      lensqtyonorderright: {
          name: "Right Quantity On Order",
          shortname: "R.Qty On Order",
          desc: "The quantity on order of right lenses attached to this line item"
      },
      lensqtyonorderleft: {
          name: "Left Quantity On Order",
          shortname: "L.Qty On Order",
          desc: "The quantity on order of left lenses attached to this line item"
      },
      lensqtyreceived: {
          name: "Quantity Received",
          shortname: "Qty Received",
          desc: "The quantity received attached to this line item"
      },
      lensqtyreceivedright: {
          name: "Right Quantity Received",
          shortname: "R.Qty Received",
          desc: "The right quantity received attached to this line item"
      },
      lensqtyreceivedleft: {
          name: "Left Quantity Received",
          shortname: "L.Qty Received",
          desc: "The left quantity received attached to this line item"
      },
      lensqtysuggested: {
          name: "Quantity Suggested",
          shortname: "Qty Suggested",
          desc: "The quantity suggested attached to this line item"
      },
      lensqtysuggestedright: {
          name: "Right Quantity Suggested",
          shortname: "R.Qty Suggested",
          desc: "The right quantity suggested attached to this line item"
      },
      lensqtysuggestedleft: {
          name: "Left Quantity Suggested",
          shortname: "L.Qty Suggested",
          desc: "The left quantity suggested attached to this line item"
      },
      lensunitprice: {
          name: "Unit Price",
          desc: "The unit price of the lens attached to this line item"
      },
      lensvendernumber: {
          name: "Vendor Number",
          shortname: "Vendor Num",
          desc: "The vendor number of the lens attached to this line item"
      },
      lens: {
          name: "Lens",
          desc: "The lens attached to this line item"
      },
      po_trays: {
          name: "Trays",
          desc: "The trays attached to this line item"
      },
      po_header: {
          name: "Purchase Order",
          shortname: "PO",
          desc: "The purchase order this line item is attached to"
      },
  }, permission_id: 'po_header')
end
