# == Schema Information
#
# Table name: store_job_data
#
#  id                        :bigint           not null, primary key
#  lenswarehousedate         :date             not null
#  lenswarehouseid           :string
#  lmssource                 :string           not null
#  storedecorpedged          :integer
#  storedecorpedgedbreak     :integer
#  storedecorpuncut          :integer
#  storedecorpuncutbreak     :integer
#  storedefinbreak           :integer
#  storedefinlenses          :integer
#  storedematrixbreak        :integer
#  storedematrixlenses       :integer
#  storedenonmatrixbreak     :integer
#  storedenonmatrixlenses    :integer
#  storedesemifinbreak       :integer
#  storedesemifinlenses      :integer
#  storedetotalbreak         :integer
#  storedetotallenses        :integer
#  storejobscompletenoinv    :integer
#  storejobscompletewithinv  :integer
#  storejobsoutstandnoinv    :integer
#  storejobsoutstandwithinv  :integer
#  storetotaljobscompleted   :integer
#  storetotaljobsoutstanding :integer
#  created_at                :datetime         not null
#  updated_at                :datetime         not null
#
# Indexes
#
#  index_store_job_data_on_lenswarehousedate  (lenswarehousedate)
#  store_jobs_unique_key                      (lenswarehouseid,lenswarehousedate,lmssource) UNIQUE
#
class StoreJobDatum < ApplicationRecord
  class << self
    def import_from_hash(h)
      h.merge!(h.delete('storejbtx') || {})
      h.merge!(h.delete('storedetx') || {})
      dedate = h.delete("storededate")
      jbdate = h.delete("storejbdate")
      h.merge!("lenswarehousedate" => dedate || jbdate)
      h['lenswarehouseid'] ||= h.delete('jblenswarehouseid') || h.delete('delenswarehouseid')
      super(h)
    end

    def conflict_target
      [:lenswarehouseid, :lenswarehousedate, :lmssource]
    end
  end

  reportable("store_job_data", "Store Job Data", "Report on store job data", {
=begin
      lmssource: {
          name: "Lab Management System",
          shortname: "LMS",
          desc: "The lab management system that produced the job data"
      },
=end
      lenswarehouseid: {
          name: "Warehouse ID",
          shortname: "Warehouse",
          desc: "The warehouse that produced the job data"
      },
      lenswarehousedate: {
          name: "Date",
          desc: "The date associated with the job data"
      },
      storedematrixlenses: {
          name: "Matrix Lenses",
          desc: "The matrix lenses for this lms/warehouse/date"
      },
      storedematrixbreak: {
          name: "Matrix Breaks",
          desc: "The matrix breaks for this lms/warehouse/date"
      },
      storedenonmatrixlenses: {
          name: "Non Matrix Lenses",
          desc: "The non matrix lenses for this lms/warehouse/date"
      },
      storedenonmatrixbreak: {
          name: "Non Matrix Breaks",
          desc: "The non matrix breaks for this lms/warehouse/date"
      },
      storedetotallenses: {
          name: "Total Lenses",
          desc: "The total lenses for this lms/warehouse/date"
      },
      storedetotalbreak: {
          name: "Total Breaks",
          desc: "The total breaks for this lms/warehouse/date"
      },
      storedesemifinlenses: {
          name: "Semi-Finished Lenses",
          desc: "The semi-finished lenses for this lms/warehouse/date"
      },
      storedesemifinbreak: {
          name: "Semi-Finished Lens Breaks",
          shortname: "Semi-Finished Breaks",
          desc: "The semi-finished lens breaks for this lms/warehouse/date"
      },
      storedefinlenses: {
          name: "Finished Lenses",
          desc: "The finished lenses for this lms/warehouse/date"
      },
      storedefinbreak: {
          name: "Finished Lens Breaks",
          shortname: "Finished Breaks",
          desc: "The finished lens breaks for this lms/warehouse/date"
      },
      storedecorpuncut: {
          name: "Corporate Uncut",
          desc: "The corporate uncut for this lms/warehouse/date"
      },
      storedecorpuncutbreak: {
          name: "Corporate Uncut Breaks",
          desc: "The corporate uncut breaks for this lms/warehouse/date"
      },
      storedecorpedged: {
          name: "Corporate Edged",
          desc: "The corporate edged for this lms/warehouse/date"
      },
      storedecorpedgedbreak: {
          name: "Corporate Edged Breaks",
          desc: "The corporate edged breaks for this lms/warehouse/date"
      },
      storejobscompletewithinv: {
          name: "Jobs Complete With Inventory",
          shortname: "Complete With Inventory",
          desc: "Jobs complete with inventory for this lms/warehouse/date"
      },
      storejobscompletenoinv: {
          name: "Jobs Complete With No Inventory",
          shortname: "Complete No Inventory",
          desc: "Jobs complete with no inventory for this lms/warehouse/date"
      },
      storejobsoutstandwithinv: {
          name: "Jobs Outstanding With Inventory",
          shortname: "Outstanding With Inventory",
          desc: "Jobs outstanding with inventory for this lms/warehouse/date"
      },
      storejobsoutstandnoinv: {
          name: "Jobs Outstanding With No Inventory",
          shortname: "Outstanding No Inventory",
          desc: "Jobs outstanding with no inventory for this lms/warehouse/date"
      },
      storetotaljobscompleted: {
          name: "Total Jobs Completed",
          shortname: "Jobs Complete",
          desc: "Total jobs completed for this lms/warehouse/date"
      },
      storetotaljobsoutstanding: {
          name: "Total Jobs Outstanding",
          shortname: "Jobs Outstanding",
          desc: "Total jobs outstanding for this lms/warehouse/date"
      },
  })
end
