# == Schema Information
#
# Table name: tax_charges
#
#  id         :bigint           not null, primary key
#  taxcode    :string
#  taxdesc    :string
#  taxprice   :decimal(12, 3)
#  created_at :datetime         not null
#  updated_at :datetime         not null
#  order_id   :bigint
#
# Indexes
#
#  index_tax_charges_on_order_id  (order_id)
#  index_tax_charges_on_taxcode   (taxcode)
#
# Foreign Keys
#
#  fk_rails_...  (order_id => orders.id) ON DELETE => cascade ON UPDATE => cascade
#
class TaxCharge < ApplicationRecord
  belongs_to :order, optional: true

  reportable("tax_charge", "Tax Charges", "Report on tax charges", {
      taxdesc: {
          name: "Description",
          shortname: "Tax",
          desc: "The name of the sales tax jurisdiction"
      },
      taxcode: {
          name: "Code",
          shortname: "Tax",
          desc: "The code of the sales tax jurisdiction"
      },
      taxprice: {
          name: "Price",
          desc: "The tax charged and payable to the relevant jurisdiction"
      },
      order: {
          name: "Order",
          desc: "The order the tax was applied to"
      }
  }, permission_id: 'order')
end
