class CorporateConsolidatedStockTransactionReport < RxModule::Reporting::ModelAutoReport
  parameter("rollforward_mode", "Rollforward Mode", "Compute balance using Lens Inventory Rollforward Rules", :boolean)
  model_target(CorporateConsolidatedStockTransaction)
  ui_hint(category: 'Inventory')

  def self.report_enabled?
    ENV['CORPORATE_RXU'] || CorporateConsolidatedStockTransaction.exists? # use this to suppress the report if the system configuration does not call for it
  end

  def model
    if rollforward?
      return @_resolved_model if @_resolved_model
      base = super.json_logic_filter(filter).group(:ccstxlenswarehouseid)
      base = base.select(:ccstxlenswarehouseid)
      base = base.select(base.get_arel('ccstxdate').maximum.as('ccstxdate'))
      base = self.class.aggregation_operations[:last_in_group][:apply].call(base, {accessor: 'ccstxendingperpetualbalance', alias: 'ccstxendingperpetualbalance', aggregation_options: {comparison_column: 'ccstxdate'}})
      base = self.class.aggregation_operations[:last_in_group][:apply].call(base, {accessor: 'ccstxperpetualbalance', alias: 'ccstxperpetualbalance', aggregation_options: {comparison_column: 'ccstxdate'}})

      beginning_balance_selector = Arel::Nodes::NamedFunction.new('Coalesce',
                                                                  [
                                                                      self.class.aggregation_operations[:first_in_group][:resolve].call({accessor: 'ccstxbeginningperpetualbalance', aggregation_options: {comparison_column: 'ccstxdate'}}),
                                                                      0,
                                                                  ])
      %w(ccstxtotalqty ccstxtotalreceiveqty ccstxtotalreceivecost ccstxtotalusageqty ccstxtotalusagecost ccstxtotalwastageqty ccstxtotalwastagecost
      ccstxtotalreturnqty ccstxtotalreturncost ccstxtotaladjustqty ccstxtotaladjustcost ccstxtotalcountvariance ccstxtotalcountvariancecost ccstxtotalpoqty
      ccstxtotalpocost ccstxtotalcyclecountqty ccstxtotalcyclecountcost ccstxperpetualbalanceadjust ccstxtotallensadjustments ccstxopenpurchases).each do |col|
        base = base.select(base.get_arel(col).sum.as(col))
      end
      base = base.select(Arel.sql(
          "#{beginning_balance_selector.to_sql} + #{%w(ccstxtotalreceivecost ccstxtotalusagecost ccstxtotalwastagecost ccstxtotalcyclecountcost ccstxtotalreturncost ccstxtotaladjustcost).map do |col|
            base.get_arel(col).sum.to_sql
          end.join(' + ')}"
      ).as('ccstxcalcendingperpetualbalance'))
      base = base.select(beginning_balance_selector.as('ccstxbeginningperpetualbalance'))
      Rails.logger.debug { {rollforward_modified_query: base.to_sql} }
      @_resolved_model = super.from(Arel.sql("(#{base.to_sql}) AS \"corporate_consolidated_stock_transactions\""))
    else
      super
    end
  end

  def using_aliases?
    super || rollforward?
  end

  def column_mappings
    (grand_total? ? (columns - grouping_columns) : columns).reduce({}) do |mappings, c|
      if using_aggregators? || using_groups? || grand_total?
        mappings[c[:accessor]] ||= {}
        mappings[c[:accessor]][c[:aggregation] || ''] = c[:alias]
      else
        mappings[c[:accessor]] = using_aliases? ? c[:alias] : c[:accessor]
      end
      mappings
    end
  end

  def rollforward?
    !!@parameters[:rollforward_mode]
  end

  def preprocess_parameters!
    if rollforward?
      Rails.logger.debug { "Running ccst in rollforward mode" }
    end
    super
  end
end