begin
  APPLICATION_ROOT = ARGV[0]
  raise "No application root supplied" unless APPLICATION_ROOT && APPLICATION_ROOT != ''

  module RxModule
    require 'win32/daemon'
    require 'puma'
    require 'puma/configuration'
    require 'dotenv'
    include Win32

    class WindowsService < Daemon
      def get_server_runner
        runner = nil
        Dir.chdir(APPLICATION_ROOT) do
          Dotenv.load
          runner = Puma::Launcher.new(Puma::Configuration.new do |c|
            c.environment "production"

            port = ENV['MODULE_PORT'] || 3000
            ssl_key_path = ENV['SSL_KEY']
            ssl_certificate_path = ENV['SSL_CERTIFICATE']
            if ssl_key_path && ssl_certificate_path
              c.bind "ssl://0.0.0.0:#{port}?key=#{ssl_key_path}&cert=#{ssl_certificate_path}"
            else
              c.bind "tcp://0.0.0.0:#{port}"
            end
          end, events: Puma::Events.stdio)
        end
        runner
      end

      def service_init
        Dir.chdir(APPLICATION_ROOT) do
          @puma = get_server_runner
        end
      end

      def service_main
        Dir.chdir(APPLICATION_ROOT) do
          @puma.run
        end
      end

      def service_pause
        Dir.chdir(APPLICATION_ROOT) do
          @puma.stop
        end
      end

      def service_resume
        Dir.chdir(APPLICATION_ROOT) do
          @puma.run
        end
      end

      def service_stop
        Dir.chdir(APPLICATION_ROOT) do
          @puma.stop
          sleep(5)
          @puma.delete_pidfile
        end
      end
    end

    WindowsService.mainloop
  end
rescue StandardError => err
  begin
    Dir.chdir(APPLICATION_ROOT) do
      File.open("./service-log.txt", 'w') do |f|
        f.puts Time.now
        f.puts err.message
        f.puts err.backtrace.join("\n\t")
      end
    end
  rescue StandardError => dirErr
    Dir.chdir(__dir__) do
      File.open("./service-log.txt", 'w') do |f|
        f.puts Time.now
        f.puts err.message
        f.puts err.backtrace.join("\n\t")
      end
    end
  end
end
