Rails.configuration.after_initialize do
  RxModule::Environment.run_site { FileMonitorConfig.run_monitor }
end

class FileMonitor
  class << self
    def file_pattern
      @_f_p ||= Regexp.new('(^.*\.xml$)|(^[^\.]+$)', Regexp::IGNORECASE)
    end

    def run_monitor(location)
      @_listener_mutex ||= Mutex.new
      @_listener_mutex.synchronize do
        Rails.logger.info { {msg: "Starting file monitor", location: location} }
        if @listener
          @listener.stop
        else
          Kernel.at_exit do
            begin
              @listener&.stop
            rescue StandardError => err
              #swallow
            end
          end
        end
        FileUtils.mkdir_p(location)
        @listener = Listen.to(location, only: file_pattern) do |modified, added|
          (modified + added).uniq.sort_by { |f| File.mtime(f) }.each do |f|
            ImportXmlJob.perform_later(f, File.size(f))
          end
        end
        Dir.entries(location)
            .map { |f| File.join(location, f) }
            .reject { |f| File.directory? f }
            .select { |f| file_pattern.match?(f) }.each do |f|
          ImportXmlJob.perform_later(f, File.size(f))
        end
        @listener.start
      end
    end
  end
end